@@ -1,4 +1,5 @@
 from jsw_nx.classes.baidu_pan import BaiduPan
+from jsw_nx.classes.baidu_fanyi import BaiduFanyi
 from jsw_nx.classes.configuration import Configuration
 from jsw_nx.classes.date import Date
 from jsw_nx.classes.fileutils import FileUtils as fileutils
@@ -14,6 +15,7 @@ from jsw_nx.packages.urljoin import urljoin
 from jsw_nx.packages.uniq_in_order import uniq_in_order
 from jsw_nx.packages.uniq import uniq
 from jsw_nx.packages.sleep_random import sleep_random
+from jsw_nx.packages.sleep import sleep
 from jsw_nx.packages.sample import sample
 from jsw_nx.packages.replace_dict_all import replace_dict_all
 from jsw_nx.packages.notify import notify
@@ -27,6 +29,8 @@ from jsw_nx.packages.env_select import env_select
 from jsw_nx.packages.deep_each import deep_each
 from jsw_nx.packages.tmpl import tmpl
 from jsw_nx.packages.qs import qs
+from jsw_nx.packages.random import random_str, random_int
+from jsw_nx.packages.random_ua import random_ua
 from jsw_nx.packages.parse_cookie import parse_cookie
 from jsw_nx.packages.param import param
 from jsw_nx.packages.days import days
@@ -49,6 +53,7 @@ from jsw_nx.base.map import map
 from jsw_nx.base.is_empty import is_empty
 from jsw_nx.base.is_blank import is_blank
 from jsw_nx.base.index import index
+from jsw_nx.base.home import home
 from jsw_nx.base.includes import includes
 from jsw_nx.base.getenv import getenv
 from jsw_nx.base.get import get
@@ -59,10 +64,12 @@ from jsw_nx.base.find_index import find_index
 from jsw_nx.base.find import find
 from jsw_nx.base.filter import filter
 from jsw_nx.base.every import every
-import pkg_resources
+from jsw_nx.scrapy_utils.url_ext import url_ext
 
-version = pkg_resources.get_distribution('jsw-nx').version
-__version__ = version
+from importlib.metadata import version
+package_version = version('jsw-nx')
+
+__version__ = package_version
 
 # next base
 
