@@ -24,7 +24,7 @@ class Weibo:
     
     参考说明：
     source: 原始图片路径 或者 base64 串
-    mode: 上传模式，可选值为 base64 或者 file
+    mode: 上传模式，可选值为 base64 | file(string) | url | buffer
     format: 图片格式，可选值为 jpg/gif
     debug: 是否开启 debug 模式，可选值为 True/False
             """
@@ -34,28 +34,45 @@ class Weibo:
     def headers(self):
         return {'Cookie': f'SUB={self.token}', 'Referer': 'https://weibo.com/'}
 
-    def __init__(self):
+    def __init__(self, **kwargs):
         lc_opt = LcOption()
         res = lc_opt.get('60f768f6d9f1465d3b1d5c43')
         self.token = res['value']
+        self.pic_host = kwargs.get('pic_host') or PIC_HOST
+
+    @classmethod
+    def get_format(cls, pid):
+        if not pid:
+            return None
+        if pid[21] == 'g':
+            return 'gif'
+        return 'jpg'
+
+    @classmethod
+    def get_pid(cls, url):
+        # https://tva1.js.work/small/da432263gy1ho5t9kynl2j20u00cqwmo.jpg
+        if not url:
+            return None
+        id_str = url.split('/')[-1].split('.')[0]
+        return int(id_str)
 
     # Get the image url by pid and size.
-    def get(self, pid, size='large', format='jpg'):
+    def get(self, pid, size='large'):
         if size not in SIZES:
             size = 'large'
-        return PIC_HOST + size + '/' + pid + '.' + format
+        return self.pic_host + size + '/' + pid + '.' + self.get_format(pid)
 
     # Get all kinds of image url by pid.
-    def getall(self, pid, format='jpg'):
+    def getall(self, pid):
         return {
-            'large': self.get(pid, 'large', format),
-            'bmiddle': self.get(pid, 'bmiddle', format),
-            'mw1024': self.get(pid, 'mw1024', format),
-            'mw690': self.get(pid, 'mw690', format),
-            'small': self.get(pid, 'small', format),
-            'square': self.get(pid, 'square', format),
-            'thumb180': self.get(pid, 'thumb180', format),
-            'thumbnail': self.get(pid, 'thumbnail', format),
+            'large': self.get(pid, 'large'),
+            'bmiddle': self.get(pid, 'bmiddle'),
+            'mw1024': self.get(pid, 'mw1024'),
+            'mw690': self.get(pid, 'mw690'),
+            'small': self.get(pid, 'small'),
+            'square': self.get(pid, 'square'),
+            'thumb180': self.get(pid, 'thumb180'),
+            'thumbnail': self.get(pid, 'thumbnail'),
         }
 
     # Upload image by url.
@@ -71,24 +88,37 @@ class Weibo:
         elif mode == 'base64':
             filep = source
             files = {'b64_data': filep}
+        elif mode == 'url':
+            res = requests.get(source, verify=False)
+            filep = res.content
+            files = {'pic1': filep}
+        elif mode == 'buffer':
+            filep = source
+            files = {'pic1': filep}
+        else:   
+            raise ValueError('Invalid mode: {}'.format(mode))
+
         url = API_URL.format(mode, fmt)
         res = requests.post(url, files=files, headers=self.headers)
         html = res.text
 
         if debug:
+            print(url, files, self.headers)
             print("Response HTML: ", html)
 
         target_str = re.findall(TARGET_RE, html)[0]
         json_data = json.loads(target_str)
-        pdata = json_data['pic_1']
+        pdata = json_data.get('pic_1')
         pid = pdata.get('pid', None)
+        response_format = self.get_format(pid)
         is_success = bool(pid) and pdata.get('width', 0) > 0
 
         if is_success:
             return {
                 'success': True,
                 'pid': pid,
-                'url': self.get(pid, 'large', fmt),
+                'url': self.get(pid, 'large'),
+                'format': response_format,
                 **pdata
             }
         else:
@@ -96,5 +126,6 @@ class Weibo:
                 'success': False,
                 'pid': None,
                 'url': None,
+                'format': None,
                 **pdata
             }
